%% Supplementary materials for the paper Bazilinskyy, P.,  Eisma. Y. B., Dodou, D., & De Winter, J. C. F. (2020). Risk perception: A study using dashcam videos and participants from different world regions. Traffic Injury Prevention.
%% Script by Joost de Winter <j.c.f.dewinter@tudelft.nl>, Pavlo Bazilinskyy <p.bazilinskyy@tudelft.nl>
clear variables;close all force;clc
opengl hardware % use OpenGL hardware for better figure quality
%% Read Excel files with raw data
[~,~,raw_rt]=xlsread('keypress_data.xlsx','A1:HSL921'); % import Excel file with RT data from the Database
[~,~,raw_cf]=xlsread('survey_data.xlsx','A2:BE1238'); % import Excel file with Figure-Eight data
temp=raw_cf(:,9);Country=cell(size(raw_cf,1),1);for i=1:length(temp);try Country(i)=unique(temp(i));catch error;Country(i)={'NaN'};end;end % Country data from the Figure-Eight data
disp(['Number of respondents in the Figure Eight database = ' num2str(size(raw_cf,1))])
disp(['Number of entries in the RT database = ' num2str(size(raw_rt,1))])
%% Process Figure-Eight data into the X matrix (1237 x 16 matrix)
temp=raw_cf(:,15);X(:,1)=strcmp(temp,'no')+2*strcmp(temp,'yes'); % Instructions understood
temp=raw_cf(:,32);X(:,2)=1*strcmp(temp,'female')+2*strcmp(temp,'male')-1*strcmp(temp,'i_prefer_not_to_respond'); % Gender
temp=raw_cf(:,31);for i=1:length(temp);try if strcmp(temp(i),'?');X(i,3)=NaN;else;X(i,3)= cell2mat(temp(i));end;catch error;X(i,3)=NaN;end;end % Age
X(X(:,3)>110,3)=NaN; % People who report age greater than 110 years
temp=raw_cf(:,14);for i=1:length(temp);try if strcmp(temp(i),'?');X(i,4)=NaN;else;X(i,4)= cell2mat(temp(i));end;catch error;X(i,4)=NaN;end;end % Age of obtaining driver's license
X(X(:,4)>110 | X(:,4)<15,4)=NaN; % People who report licence more than 110 years
temp=raw_cf(:,33);X(:,5)=1*strcmp(temp,'private_vehicle')+2*strcmp(temp,'public_transportation')+3*strcmp(temp,'motorcycle')+4*strcmp(temp,'walkingcycling')+5*strcmp(temp,'other')-1*strcmp(temp,'i_prefer_not_to_respond');  % Primary mode of transportation
temp=raw_cf(:,28);X(:,6)=1*strcmp(temp,'never')+2*strcmp(temp,'less_than_once_a_month')+3*strcmp(temp,'once_a_month_to_once_a_week')+4*strcmp(temp,'1_to_3_days_a_week')+5*strcmp(temp,'4_to_6_days_a_week')+6*strcmp(temp,'every_day')-1*strcmp(temp,'i_prefer_not_to_respond'); % How many times in past 12 months did you drive a vehicle
temp=raw_cf(:,13);for i=1:length(temp);try X(i,7)=1+cell2mat(temp(i));catch error;X(i,7)=1*strcmp(temp(i),'0_km__mi')+2*strcmp(temp(i),'1__1000_km_1__621_mi')+3*strcmp(temp(i),'1001__5000_km_622__3107_mi')+4*strcmp(temp(i),'5001__15000_km_3108__9321_mi')+5*strcmp(temp(i),'15001__20000_km_9322__12427_mi')+6*strcmp(temp(i),'20001__25000_km_12428__15534_mi')+7*strcmp(temp(i),'25001__35000_km_15535__21748_mi')+8*strcmp(temp(i),'35001__50000_km_21749__31069_mi')+9*strcmp(temp(i),'50001__100000_km_31070__62137_mi')+10*strcmp(temp(i),'more_than_100000_km_more_than_62137_mi')-1*strcmp(temp(i),'i_prefer_not_to_respond');end;end % Mileage
temp=raw_cf(:,16);for i=1:length(temp);try X(i,8)=1+cell2mat(temp(i));catch error;X(i,8)=7*strcmp(temp(i),'more_than_5')-1*strcmp(temp(i),'i_prefer_not_to_respond');end;end % Number of accidents
temp=raw_cf(:,17:23);X(:,9:15)=1*strcmp(temp,'0_times_per_month')+2*strcmp(temp,'1_to_3_times_per_month')+3*strcmp(temp,'4_to_6_times_per_month')+4*strcmp(temp,'7_to_9_times_per_month')+5*strcmp(temp,'10_or_more_times_per_month')-1*strcmp(temp,'i_prefer_not_to_respond'); % Driving behaviour DBQ
temp=raw_cf(:,27);for i=1:length(temp);try if strcmp(temp(i),'?'); X(i,16)=NaN;else;X(i,16)=cell2mat(temp(i));end;catch error;X(i,16)=NaN;end;end % in_which_year_do_you_think_that_most_cars_will_be_able_to_drive_fully_automatically_in_your_country_of_residence
temp=find(X(:,16)<2018);X(temp,16)=NaN; % People who report a number less than 2014
for i=1:size(raw_cf,1);X(i,21)=24*3600*(datenum(raw_cf{i,2})-datenum(raw_cf{i,4}));end %% Compute survey time and store in the 17th column of the X matrix
X(:,22)=tiedrank(X(:,21))./size(X,1); % ranking the survey time
X(X<=0)=NaN; % Put missing values (0) or no response (-1) at NaN
X(isnan(sum(X(:,9:15),2)),9:15)=NaN; % for the DBQ put all 7 items at NaN if any of the 7 items is NaN
X(:,9:15)=tiedrank(X(:,9:15))./repmat(sum(~isnan(X(:,9:15))),size(X,1),1); % ranking of DBQ scores so that these scores become comparable between surveys
X(:,18)=cell2mat(raw_cf(:,1)); % Store Figure-Eight ID in the 18th column
for i=1:size(raw_cf,1);id_str = raw_cf{i,57};X(i,19) = str2double(id_str(regexp(id_str,'DANGER')+6:end));end % Extract participant IDs from Figure-Eight data
%% Find RT and store them in Xrtrt matrix
IDrt=NaN(size(X,1),1); % DANGER codes
Xrtv=NaN(size(X,1),16); % matrix with video presentation orders
[Xrtrt,Xrtrtorder]=deal(NaN(size(X,1),16,1200)); % number of participants x 16 videos x a maximum of 1088 key presses
Xrt=NaN(size(X,1),18); % Start times

for i=1:size(raw_rt,1) % loop across all 921 lines of the RT data
    temp=raw_rt{i,10};temp2=regexp(temp,'"');IDrt(i)=str2double(temp(regexp(temp,'DANGER')+6:temp2(end)-1)); % DANGER codes
end
IDrt2=IDrt;
for i=1:size(raw_rt,1) % loop across all 921 lines of the RT data
    temp=find(ismember(IDrt2,IDrt2(i)));
    if length(temp)>1 % iIDrtf there is a douplicate
        IDrt2(temp(1):temp(end-1))=-9999; % keep only the last if there are duplicate DANGER codes
    end
end
raw_rt(IDrt2==-9999,:)=[];IDrt(IDrt2==-9999)=[]; % remove the duplicate DANGER codes

for i=1:size(X,1) % loop across all lines of the Figure-Eight data
    if sum(IDrt==X(i,19)) % participant can be found in the RT data
        rt_data=raw_rt(IDrt==X(i,19),:); % find this Figure-Eight participant in the RT data
        [vid,tecounter]=deal(0);
        for i2=1:size(rt_data,2) % loop over the RT info for that participant
            temp=rt_data{i2};
            if isnan(temp) % if data ends, then go to the next participant
                break
            end
            if regexp(temp,'"video_') % if a new video is found
                vid=vid+1;
                rt=0;
                Xrtv(i,vid)=str2double(temp(regexp(temp,'video_')+6:end-1)); % vid = video number presentation order, stored number is video shown
            end
            if regexp(temp,'time_elapsed')
                tecounter=tecounter+1;
                Xrt(i,tecounter)=str2double(temp(regexp(temp,'time_elapsed')+13:end)); % time elapsed at start
            end
            if regexp(temp,'"rt":')
                rt=rt+1; % reaction time index for that video
                Xrtrt(i, Xrtv(i,vid),rt)=str2double(temp(regexp(temp,'"rt":')+5:end)); % vid = video number presentation order
            end
        end
    end
end
%% Transform Xrtrt matrix (with RTs) to Xrtrtf (containing 0s and 1s as a function of time). Xrtrtf is a participant x 16 video x 700 time sample matrix
Xrtrtf=zeros(size(Xrtrt,1),size(Xrtrt,2),700); % start with a matrix of zeros
for i=1:size(Xrtrt,1) % loop over participants
    for i2=1:size(Xrtrt,2) % loop over videos
        temp=squeeze(Xrtrt(i,i2,:))/1000;temp(isnan(temp))=[]; % RTs for that video and participant
        for i3=length(temp):-1:2
            if temp(i3)-temp(i3-1)<0.1 % if there is less than 0.1 s between key presses
                temp(i3)=[]; % remove the key press
            end
        end
        temp=1+10*round(temp,1);
        temp(temp>700)=[];
        Xrtrtf(i,i2,temp)=1; % store 1 in Xrtrtf matrix (participants x video x time)
    end
    if isnan(Xrt(i,1));Xrtrtf(i,:,:)=NaN;end
end
%% Find rows with identical IP addresses
[IPCF,y]=deal(NaN(size(raw_cf,1),1)); % initialize variables (1237 x 1 vector
for i=1:size(raw_cf,1)
    IPCF(i)=str2double(strrep(raw_cf(i,12),'.',''));
end % reduce IP addresses of Figure-Eight to a single number
for i=1:size(X,1) % loop over all rows
    temp=find(IPCF==IPCF(i));
    if length(temp)==1 % if the IP address occurs only once
        y(i)=1; % keep
    elseif length(temp)>1 % if the IP addres occurs more than once
        y(temp(1))=1; % keep the first survey for that IP address
        y(temp(2:end))=2; % no not keep the other ones
    end
end
invalid5=find(y>1); % respondents who completed the survey more than once from the same IP address
%% Same as Xrtrtf but now sorted on video order of presentation rather than video number
Xrtrtforder=NaN(size(Xrtrtf));
for i=1:size(Xrtrtf,1)
    for i2=1:size(Xrtrtf,2)
        if ~isnan(Xrtv(i,i2))
            Xrtrtforder(i,i2,:)=squeeze(Xrtrtf(i,Xrtv(i,i2),:));
        end
    end
end
%% If the video is delayed (>61 s) then remove data for that video
timedifference=diff(Xrt')';timedifference(:,9)=[];
for i=1:size(Xrtrtf,1)
    for i2=1:size(Xrtrtf,2)
        if timedifference(i,i2)>61000
            Xrtrtf(i,Xrtv(i,vid),:)=NaN; % if there is a problem with the video, put it at NaN
        end
    end
end
%% Remove participants who did not meet inclusion criteria
invalid1 = find(X(:,1)==1); % respondents who did not read instructions
invalid2 = find(X(:,3)<18); % respondents who indicated they are under 18 years old
invalid3 = find(sum(nansum(Xrtrtf(:,:,1:600),3),2)==0); % respondents who did not press the key at all
invalid3a = find(sum(nansum(Xrtrtforder(:,1:8,1:600),3),2)==0); % respondents who did not press the key at all, first half of the experiment
invalid3b = find(sum(nansum(Xrtrtforder(:,9:16,1:600),3),2)==0); % respondents who did not press the key at all, second half of the experiment
invalid3c = find(max((squeeze(nansum(Xrtrtf(:,1:16,1:600),3))),[],2)>100); % respondents who press the key more than 100 times in a video
invalid4=find(X(:,21)<1000); % viewing the videos would take at 960 s, faster than 1000 s for the entire video seems impossible
invalid = unique([invalid1;invalid2;invalid3a;invalid3b;invalid3c;invalid4;invalid5]); % Add together all invalid rows with data
% filter data
X(invalid,:)=[];
Country(invalid)=[];
Xrtrtf(invalid,:,:)=[];
raw_cf(invalid,:)=[];
Xrtrt(invalid,:,:)=[];
Xrtrtforder(invalid,:,:)=[];
%% Statistical output
disp(['Number of respondents who did not read instructions = ' num2str(length(invalid1))])
disp(['Number of respondents under 18 = ' num2str(length(invalid2))])
disp(['Number of respondents who did not press the key at all in the first half of the experiment = ' num2str(length(invalid3a))])
disp(['Number of respondents who did not press the key at all in the second half of the experiment = ' num2str(length(invalid3b))])
disp(['Number of respondents who pressed the key more than 100 times in a video = ' num2str(length(invalid3c))])
disp(['Fast respondents = ' num2str(length(invalid4))])
disp(['Respondents with double IP address = ' num2str(length(invalid5))])
disp(['Number of respondents removed = ' num2str(length(invalid))])
disp(['Number of respondents included in the analysis = ' num2str(size(X,1))]);
disp(['Number of countries included in the analysis = ' num2str(length(unique(Country)))]);
%% Gender and age information
disp(['Gender, male respondents = ' num2str(sum(X(:,2)==2))])
disp(['Gender, female respondents = ' num2str(sum(X(:,2)==1))])
disp(['Gender, I prefer not to respond = ' num2str(sum(isnan(X(:,2))))])
disp(['Age, mean = ' num2str(nanmean(X(:,3)))])
disp(['Age, SD = ' num2str(nanstd(X(:,3)))])
disp(['Age, NaN = ' num2str(sum(isnan(X(:,3))))])
disp(['Age of obtaining license, mean = ' num2str(nanmean(X(:,4)))])
disp(['Age of obtaining license, SD = ' num2str(nanstd(X(:,4)))])
disp(['Age of obtaining license, NaN = ' num2str(sum(isnan(X(:,4))))])
%% Common countries
[country_unique, ~, ub] = unique(Country);
test2counts = histc(ub, 1:length(country_unique)); %#ok<HISTC>
[B,I] = maxk(test2counts,3);
disp('Most common countries: ')
disp(country_unique(I))
disp(B)
WesternEurope=find(strcmp(Country,'AUT')|strcmp(Country,'BEL')|strcmp(Country,'DEU')|strcmp(Country,'DNK')|strcmp(Country,'FIN')|strcmp(Country,'FRA')|strcmp(Country,'NLD')|strcmp(Country,'SWE'));
Other=find(~strcmp(Country,'VEN') & ~strcmp(Country,'IND') & ~strcmp(Country,'USA') & ~strcmp(Country,'AUT') & ~strcmp(Country,'BEL') & ~strcmp(Country,'DEU') & ~strcmp(Country,'DNK') & ~strcmp(Country,'FIN') & ~strcmp(Country,'FRA') & ~strcmp(Country,'NLD') & ~strcmp(Country,'SWE'));
disp(['Western Europe: ' num2str(length(WesternEurope))]);
disp(['Other countries: ' num2str(length(Other))]);
COUNTRIES_SELECTED=country_unique(I);
%% Most common countries in the Other category
[country_unique_other, ~, ub] = unique(Country(Other));
test2counts = histc(ub, 1:length(country_unique_other)); %#ok<HISTC>
[B,I] = maxk(test2counts,10);
disp('Most common countries in the Other category: ')
disp(country_unique_other(I))
disp(B)
%% Survey completion time
disp(['Survey time mean = ' num2str(nanmean(X(:,21)/60))]);
disp(['Survey time SD = ' num2str(nanstd(X(:,21)/60))]);
disp(['Survey time Median = ' num2str(nanmedian(X(:,21))/60)]);
%% Colours for output
gc=[188 32 48; 0 255 0; 42 100 254;255 160 0;200 200 200]/255;
%% Mean number of response key presses per video. The error bars represent 95% confidence intervals.
ORD=[6 8 7 5     16 15 14 13       10 12 11 9      2 4 3 1];
VR=sum(Xrtrtf(:,ORD,1:600),3); % Mean risk score per person and video

Regions={'India'
    'India'
    'India'
    'India'
    'Venezuela'
    'Venezuela'
    'Venezuela'
    'Venezuela'
    'United States'
    'United States'
    'United States'
    'United States'
    'Western Europe'
    'Western Europe'
    'Western Europe'
    'Western Europe'};

Environments={'Highway'
    'Secondary road'
    'Non-busy city'
    'Busy city'
    'Highway'
    'Secondary road'
    'Non-busy city'
    'Busy city'
    'Highway'
    'Secondary road'
    'Non-busy city'
    'Busy city'
    'Highway'
    'Secondary road'
    'Non-busy city'
    'Busy city'};

p=NaN(16,16);
for c1=1:16
    for c2=1:16
        if c2>c1
            [~,p(c1,c2),~,stats] = ttest(VR(:,c1),VR(:,c2)); % Perform paired t test
            if p(c1,c2)>=0.005
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p = ' sprintf('%0.3f',p(c1,c2)) ' (not statistically significant)'])
            elseif p(c1,c2)>=0.001
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p = ' sprintf('%0.3f',p(c1,c2)) ' (statistically significant'])
            elseif p(c1,c2)<0.001
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p < 0.001 (statistically significant)'])
            end
        end
    end
end
disp(['From the ' num2str(sum(sum(p>=0))) ' possible pairwise comparisons between the 16 videos (all five participant groups aggregated), a total of ' num2str(sum(sum(p<0.005))) ' comparisons were statistically significantly different from each other (p < .005).'])
%% Comparisons between participant groups
disp(' ')
p=NaN(4,5);
disp('Comparisons between participant groups')
for c1=1:5
    for c2=1:5
        if c2>c1
            if c1==1
                v1=nanmean(VR(strcmp(Country,'USA'),:),2);
            elseif c1==2
                v1=nanmean(VR(strcmp(Country,'VEN'),:),2);
            elseif c1==3
                v1=nanmean(VR(strcmp(Country,'IND'),:),2);
            elseif c1==4
                v1=nanmean(VR(WesternEurope,:),2);
            elseif c1==5
                v1=nanmean(VR(Other,:),2);
            end
            if c2==1
                v2=nanmean(VR(strcmp(Country,'USA'),:),2);
            elseif c2==2
                v2=nanmean(VR(strcmp(Country,'VEN'),:),2);
            elseif c2==3
                v2=nanmean(VR(strcmp(Country,'IND'),:),2);
            elseif c2==4
                v2=nanmean(VR(WesternEurope,:),2);
            elseif c2==5
                v2=nanmean(VR(Other,:),2);
            end
            [~,p(c1,c2),~,stats] = ttest2(v1,v2,'vartype','unequal'); % Perform t test
            if p(c1,c2)>=0.005
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p = ' sprintf('%0.3f',p(c1,c2)) ' (not statistically significant)'])
            elseif p(c1,c2)>=0.001
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p = ' sprintf('%0.3f',p(c1,c2)) ' (statistically significant'])
            elseif p(c1,c2)<0.001
                disp(['Condition ' num2str(c1) ' vs. Condition ' num2str(c2) ' : t(' num2str(stats.df) ') = ' sprintf('%0.2f',stats.tstat) ', p < 0.001 (statistically significant)'])
            end
        end
    end
end
%% Number of key presses
V3=[nanmean(VR(strcmp(Country,'USA'),:))' nanmean(VR(strcmp(Country,'VEN'),:))' nanmean(VR(strcmp(Country,'IND'),:))' nanmean(VR(WesternEurope,:))' nanmean(VR(Other,:))'];
V3SD=[nanstd(VR(strcmp(Country,'USA'),:))' nanstd(VR(strcmp(Country,'VEN'),:))' nanstd(VR(strcmp(Country,'IND'),:))' nanstd(VR(WesternEurope,:))' nanstd(VR(Other,:))'];
figure;b=barh(V3);hold on;box off
for i=1:5
    b(i).FaceColor = 'flat';
    b(i).CData(1:4,:)=repmat(gc(1,:),4,1);
    b(i).CData(5:8,:)=repmat(gc(2,:),4,1);
    b(i).CData(9:12,:)=repmat(gc(3,:),4,1);
    b(i).CData(13:16,:)=repmat(gc(4,:),4,1);
end
[ctr,ydt]=deal(NaN(5,16));
for k1 = 1:5
    ctr(k1,:) = bsxfun(@plus, b(k1).XData, [b(k1).XOffset]');
    ydt(k1,:) = b(k1).YData;
end
for i=1:16
    text(-10,ctr(2,i),Regions(i),'fontsize',20,'horizontalalignment','left')
    text(-10,ctr(4,i),Environments(i),'fontsize',20,'horizontalalignment','left')
end

set(gca,'ytick',1:16,'yticklabel',[],'xlim',[0 14.5],'tickdir','out','ticklength',[0.01 0.00],'xtick',0:2:100,'ydir','reverse','ytick',-9999)
xlabel('Mean number of key presses','Fontsize',16,'Fontname','Arial')
fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',12)
for i=1:5
    for i2=1:16
        if i==1
            text(-0.1,ctr(i,i2),'United States','horizontalalignment','right','fontsize',7,'color','k')
            text(ydt(i,i2)+0.1,ctr(i,i2),[sprintf('%0.2f',V3(i2,i)) ' (' sprintf('%0.2f',V3SD(i2,i)) ')'],'fontsize',7,'color','k','verticalalignment','middle')
        elseif i==2
            text(-0.1,ctr(i,i2),'Venezuela','horizontalalignment','right','fontsize',7,'color','k')
            text(ydt(i,i2)+0.1,ctr(i,i2),[sprintf('%0.2f',V3(i2,i)) ' (' sprintf('%0.2f',V3SD(i2,i)) ')'],'fontsize',7,'color','k','verticalalignment','middle')
        elseif i==3
            text(-0.1,ctr(i,i2),'India','horizontalalignment','right','fontsize',7,'color','k')
            text(ydt(i,i2)+0.1,ctr(i,i2),[sprintf('%0.2f',V3(i2,i)) ' (' sprintf('%0.2f',V3SD(i2,i)) ')'],'fontsize',7,'color','k','verticalalignment','middle')
        elseif i==4
            text(-0.1,ctr(i,i2),'Western Europe','horizontalalignment','right','fontsize',7,'color','k')
            text(ydt(i,i2)+0.1,ctr(i,i2),[sprintf('%0.2f',V3(i2,i)) ' (' sprintf('%0.2f',V3SD(i2,i)) ')'],'fontsize',7,'color','k','verticalalignment','middle')
        else
            text(-0.1,ctr(i,i2),'Other','horizontalalignment','right','fontsize',7,'color','k')
            text(ydt(i,i2)+0.1,ctr(i,i2),[sprintf('%0.2f',V3(i2,i)) ' (' sprintf('%0.2f',V3SD(i2,i)) ')'],'fontsize',7,'color','k','verticalalignment','middle')
        end
    end
end
set(gcf,'pos',[100 50 500 950])
set(gca,'pos',[0.41 0.06 0.58 0.94])
%% Participant stats (definition of variables as in Table 1 of the paper)
disp('Table 1')
Y(1,1:5)=[sum(strcmp(Country,'USA')) sum(strcmp(Country,'VEN')) sum(strcmp(Country,'IND')) length(WesternEurope) length(Other)]; % Number of participants
Y(2,1:5)=[round(nanmean(X(strcmp(Country,'USA'),3)),2) round(nanmean(X(strcmp(Country,'VEN'),3)),2) round(nanmean(X(strcmp(Country,'IND'),3)),2) round(nanmean(X(WesternEurope,3)),2) round(nanmean(X(Other,3)),2)];
Y(3,1:5)=[round(nanstd(X(strcmp(Country,'USA'),3)),2) round(nanstd(X(strcmp(Country,'VEN'),3)),2) round(nanstd(X(strcmp(Country,'IND'),3)),2) round(nanstd(X(WesternEurope,3)),2) round(nanstd(X(Other,3)),2)];
Y(4,1:5)=100*([round(nanmean(X(strcmp(Country,'USA'),2)),2) round(nanmean(X(strcmp(Country,'VEN'),2)),2) round(nanmean(X(strcmp(Country,'IND'),2)),2) round(nanmean(X(WesternEurope,2)),2) round(nanmean(X(Other,2)),2)]-1);
Y(5,1:5)=[sum(X(strcmp(Country,'USA'),2)==2) sum(X(strcmp(Country,'VEN'),2)==2) sum(X(strcmp(Country,'IND'),2)==2) sum(X(WesternEurope,2)==2) sum(X(Other,2)==2)];
Y(6,1:5)=[round(nanmean(X(strcmp(Country,'USA'),4)),2) round(nanmean(X(strcmp(Country,'VEN'),4)),2) round(nanmean(X(strcmp(Country,'IND'),4)),2) round(nanmean(X(WesternEurope,4)),2) round(nanmean(X(Other,4)),2)];
Y(7,1:5)=[round(nanstd(X(strcmp(Country,'USA'),4)),2) round(nanstd(X(strcmp(Country,'VEN'),4)),2) round(nanstd(X(strcmp(Country,'IND'),4)),2) round(nanstd(X(WesternEurope,4)),2) round(nanstd(X(Other,4)),2)];
Y(8,1:5)=[round(100*nanmean(X(strcmp(Country,'USA'),5)==1)) round(100*nanmean(X(strcmp(Country,'VEN'),5)==1)) round(100*nanmean(X(strcmp(Country,'IND'),5)==1)) round(100*nanmean(X(WesternEurope,5)==1)) round(100*nanmean(X(Other,5)==1))];
Y(9,1:5)=[round(100*nanmean(X(strcmp(Country,'USA'),5)==3)) round(100*nanmean(X(strcmp(Country,'VEN'),5)==3)) round(100*nanmean(X(strcmp(Country,'IND'),5)==3)) round(100*nanmean(X(WesternEurope,5)==3)) round(100*nanmean(X(Other,5)==3))];
Y(10,1:5)=[round(nanmean(X(strcmp(Country,'USA'),6)),2) round(nanmean(X(strcmp(Country,'VEN'),6)),2) round(nanmean(X(strcmp(Country,'IND'),6)),2) round(nanmean(X(WesternEurope,6)),2) round(nanmean(X(Other,6)),2)];
Y(11,1:5)=[round(nanstd(X(strcmp(Country,'USA'),6)),2) round(nanstd(X(strcmp(Country,'VEN'),6)),2) round(nanstd(X(strcmp(Country,'IND'),6)),2) round(nanstd(X(WesternEurope,6)),2) round(nanstd(X(Other,6)),2)];
Y(12,1:5)=[round(nanmean(X(strcmp(Country,'USA'),7)),2) round(nanmean(X(strcmp(Country,'VEN'),7)),2) round(nanmean(X(strcmp(Country,'IND'),7)),2) round(nanmean(X(WesternEurope,7)),2) round(nanmean(X(Other,7)),2)];
Y(13,1:5)=[round(nanstd(X(strcmp(Country,'USA'),7)),2) round(nanstd(X(strcmp(Country,'VEN'),7)),2) round(nanstd(X(strcmp(Country,'IND'),7)),2) round(nanstd(X(WesternEurope,7)),2) round(nanstd(X(Other,7)),2)];
Y(14,1:5)=-1+[round(nanmean(X(strcmp(Country,'USA'),8)),2) round(nanmean(X(strcmp(Country,'VEN'),8)),2) round(nanmean(X(strcmp(Country,'IND'),8)),2) round(nanmean(X(WesternEurope,8)),2) round(nanmean(X(Other,8)),2)];
Y(15,1:5)=[round(nanstd(X(strcmp(Country,'USA'),8)),2) round(nanstd(X(strcmp(Country,'VEN'),8)),2) round(nanstd(X(strcmp(Country,'IND'),8)),2) round(nanstd(X(WesternEurope,8)),2) round(nanstd(X(Other,8)),2)];
disp(Y)
%% Perform statistical tests
V=1:16;T=1:50:551;
p=NaN(16,12);fe=NaN(16,12,10);chistat=NaN(16,12);Proportion=NaN(16,12,5);
for i=1:length(V) % loop over 16 videos
    for i2=1:length(T) % loop over time vector
        n1=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'USA'),ORD(V(i)),T(i2):T(i2)+49)),2))==1); % number of participants who pressed the key once of more in that 5 s time interval
        N1=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'USA'),ORD(V(i)),T(i2):T(i2)+49)),2))>=0); % number of participants with data in that time interval
        n2=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'VEN'),ORD(V(i)),T(i2):T(i2)+49)),2))==1); % number of participants who pressed the key once of more in that 5 s time interval
        N2=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'VEN'),ORD(V(i)),T(i2):T(i2)+49)),2))>=0); % number of participants with data in that time interval
        n3=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'IND'),ORD(V(i)),T(i2):T(i2)+49)),2))==1); % number of participants who pressed the key once of more in that 5 s time interval
        N3=sum(sign(sum(squeeze(Xrtrtf(strcmp(Country,'IND'),ORD(V(i)),T(i2):T(i2)+49)),2))>=0); % number of participants with data in that time interval
        n4=sum(sign(sum(squeeze(Xrtrtf(WesternEurope,ORD(V(i)),T(i2):T(i2)+49)),2))==1); % number of participants who pressed the key once of more in that 5 s time interval
        N4=sum(sign(sum(squeeze(Xrtrtf(WesternEurope,ORD(V(i)),T(i2):T(i2)+49)),2))>=0); % number of participants with data in that time interval
        n5=sum(sign(sum(squeeze(Xrtrtf(Other,ORD(V(i)),T(i2):T(i2)+49)),2))==1); % number of participants who pressed the key once of more in that 5 s time interval
        N5=sum(sign(sum(squeeze(Xrtrtf(Other,ORD(V(i)),T(i2):T(i2)+49)),2))>=0); % number of participants with data in that time interval
        Region15=[ones(size(find(strcmp(Country,'USA'))));2*ones(size(find(strcmp(Country,'VEN'))));3*ones(size(find(strcmp(Country,'IND'))));4*ones(size(WesternEurope));5*ones(size(Other))];
        KeyPress15=[sign(sum(squeeze(Xrtrtf(strcmp(Country,'USA'),ORD(V(i)),T(i2):T(i2)+49)),2));sign(sum(squeeze(Xrtrtf(strcmp(Country,'VEN'),ORD(V(i)),T(i2):T(i2)+49)),2));sign(sum(squeeze(Xrtrtf(strcmp(Country,'IND'),ORD(V(i)),T(i2):T(i2)+49)),2));sign(sum(squeeze(Xrtrtf(WesternEurope,ORD(V(i)),T(i2):T(i2)+49)),2));sign(sum(squeeze(Xrtrtf(Other,ORD(V(i)),T(i2):T(i2)+49)),2))];
        [p(i,i2),chistat(i,i2)]=chisquaretest(n1,N1,n2,N2,n3,N3,n4,N4,n5,N5); % perform chi-square test
        Proportion(i,i2,1)=n1/N1; % proportion of participants per participant group who had pressed the response key at least once within that 5 s time interval
        Proportion(i,i2,2)=n2/N2; % proportion of participants per participant group who had pressed the response key at least once within that 5 s time interval
        Proportion(i,i2,3)=n3/N3; % proportion of participants per participant group who had pressed the response key at least once within that 5 s time interval
        Proportion(i,i2,4)=n4/N4; % proportion of participants per participant group who had pressed the response key at least once within that 5 s time interval
        Proportion(i,i2,5)=n5/N5; % proportion of participants per participant group who had pressed the response key at least once within that 5 s time interval
        x1 = [n1 N1-n1;n2 N2-n2];[~,fe(i,i2,1)] = fishertest(x1); % perform Fisher's exact test
        x2 = [n1 N1-n1;n3 N3-n3];[~,fe(i,i2,2)] = fishertest(x2);
        x3 = [n1 N1-n1;n4 N4-n4];[~,fe(i,i2,3)] = fishertest(x3);
        x4 = [n1 N1-n1;n5 N5-n5];[~,fe(i,i2,4)] = fishertest(x4);
        x5 = [n2 N2-n2;n3 N3-n3];[~,fe(i,i2,5)] = fishertest(x5);
        x6 = [n2 N2-n2;n4 N4-n4];[~,fe(i,i2,6)] = fishertest(x6);
        x7 = [n2 N2-n2;n5 N5-n5];[~,fe(i,i2,7)] = fishertest(x7);
        x8 = [n3 N3-n3;n4 N4-n4];[~,fe(i,i2,8)] = fishertest(x8);
        x9 = [n3 N3-n3;n5 N5-n5];[~,fe(i,i2,9)] = fishertest(x9);
        x10 = [n4 N4-n4;n5 N5-n5];[~,fe(i,i2,10)] = fishertest(x10);
    end
end
%% Mean cumulative number of key presses per participant
time=0.1:.1:60;
YMAX=[9 10 13 11 1.8 5 4 9 4 1 6.5 4.5 1 1.4 1.6 12]; % used for defining the yrange of the plots
Title={'India, Highway'
    'India, Secondary road'
    'India, Non-busy city'
    'India, Busy city'
    'Venezuela, Highway'
    'Venezuela, Secondary road'
    'Venezuela, Non-busy city'
    'Venezuela, Busy city'
    'United States, Highway'
    'United States, Secondary road'
    'United States, Non-busy city'
    'United States, Busy city'
    'Western Europe, Highway'
    'Western Europe, Secondary road'
    'Western Europe, Non-busy city'
    'Western Europe, Busy city'};
for i=1:length(ORD) % loop over time vector
    tempa=cumsum(nanmean(squeeze(Xrtrtf(strcmp(Country,'USA'),ORD(i),1:600))));
    tempb=cumsum(nanmean(squeeze(Xrtrtf(strcmp(Country,'VEN'),ORD(i),1:600))));
    tempc=cumsum(nanmean(squeeze(Xrtrtf(strcmp(Country,'IND'),ORD(i),1:600))));
    tempd=cumsum(nanmean(squeeze(Xrtrtf(WesternEurope,ORD(i),1:600))));
    tempe=cumsum(nanmean(squeeze(Xrtrtf(Other,ORD(i),1:600))));
    figure;hold on
    for i2=1:length(T)
        plot([(T(i2)-1)/10+5 (T(i2)-1)/10+5],[0 YMAX(i)*1.3],'linewidth',.25,'color',[.8 .8 .8])
    end
    box off
    h1=plot(time,tempa,'-','Linewidth',3,'color',gc(1,:));
    h2=plot(time,tempb,'-','Linewidth',3,'color',gc(2,:));
    h3=plot(time,tempc,'-','Linewidth',3,'color',gc(3,:));
    h4=plot(time,tempd,'-','Linewidth',3,'color',gc(4,:));
    h5=plot(time,tempe,'-','Linewidth',3,'color',gc(5,:));
    for i2=1:length(T)
        [sign1,sign2,sign3,sign4,sign5]=deal([]);
        if fe(i,i2,1)<0.005;sign1=[sign1 'V'];sign2=[sign2 'U'];end %#ok<*AGROW>
        if fe(i,i2,2)<0.005;sign1=[sign1 'I'];sign3=[sign3 'U'];end
        if fe(i,i2,3)<0.005;sign1=[sign1 'W'];sign4=[sign4 'U'];end
        if fe(i,i2,4)<0.005;sign1=[sign1 'O'];sign5=[sign5 'U'];end
        if fe(i,i2,5)<0.005;sign2=[sign2 'I'];sign3=[sign3 'V'];end
        if fe(i,i2,6)<0.005;sign2=[sign2 'W'];sign4=[sign4 'V'];end
        if fe(i,i2,7)<0.005;sign2=[sign2 'O'];sign5=[sign5 'V'];end
        if fe(i,i2,8)<0.005;sign3=[sign3 'W'];sign4=[sign4 'I'];end
        if fe(i,i2,9)<0.005;sign3=[sign3 'O'];sign5=[sign5 'I'];end
        if fe(i,i2,10)<0.005;sign4=[sign4 'O'];sign5=[sign5 'O'];end
        if ~isempty(sign1);sign1=['(' sign1 ')'];end
        if ~isempty(sign2);sign2=['(' sign2 ')'];end
        if ~isempty(sign3);sign3=['(' sign3 ')'];end
        if ~isempty(sign4);sign4=['(' sign4 ')'];end
        if ~isempty(sign5);sign5=['(' sign5 ')'];end
        text((T(i2)-1)/10+0.3,YMAX(i)*1.27,[num2str(round(100*Proportion(i,i2,1))) '% ' sign1],'horizontalalignment','left','color',gc(1,:))
        text((T(i2)-1)/10+0.3,YMAX(i)*1.22,[num2str(round(100*Proportion(i,i2,2))) '% ' sign2],'horizontalalignment','left','color',gc(2,:))
        text((T(i2)-1)/10+0.3,YMAX(i)*1.17,[num2str(round(100*Proportion(i,i2,3))) '% ' sign3],'horizontalalignment','left','color',gc(3,:))
        text((T(i2)-1)/10+0.3,YMAX(i)*1.12,[num2str(round(100*Proportion(i,i2,4))) '% ' sign4],'horizontalalignment','left','color',gc(4,:))
        text((T(i2)-1)/10+0.3,YMAX(i)*1.07,[num2str(round(100*Proportion(i,i2,5))) '% ' sign5],'horizontalalignment','left','color',gc(5,:))
        text((T(i2)-1)/10+0.3,YMAX(i)*1.01,['\chi^2 = ' sprintf('%0.1f',chistat(i,i2))],'horizontalalignment','left','color',[0 0 0])
        if p(i,i2)<0.001
            text((T(i2)-1)/10+0.3,YMAX(i)*0.94,'\it{p}\rm < 0.001','horizontalalignment','left','color',[0 0 0])
        else
            text((T(i2)-1)/10+0.3,YMAX(i)*0.94,['\it{p}\rm = ' sprintf('%0.3f',p(i,i2))],'horizontalalignment','left','color',[0 0 0])
        end
    end
    if i>1;title(Title{i});end % Plot title, except for the Indian Highway (per journal style)
    xlabel('Time (s)')
    ylabel('Mean cumulative number of key presses per participant')
    h=legend([h1 h2 h3 h4 h5],['Participants from the USA (\it{n}\rm = ' num2str(Y(1,1)) ')'],['Participants from Venezuela (\it{n}\rm = ' num2str(Y(1,2)) ')'],['Participants from India (\it{n}\rm = ' num2str(Y(1,3)) ')'],['Participants from Western Europe (\it{n}\rm = ' num2str(Y(1,4)) ')'],['Other participants (\it{n}\rm = ' num2str(Y(1,5)) ')'],'location','northwest');
    set(h,'Position',[0.07 0.48 0.26 0.15])
    set(gca,'ylim',[0 YMAX(i)*1.3],'tickdir','out','xtick',0:5:60, 'LooseInset', [0.01 0.01 0.01 0.01])
    fig=gcf;set(findall(fig,'-property','FontName'),'FontName','Arial','Fontsize',19)
    set(gca,'children',flipud(get(gca,'children')))
end
%% Supplementary function for output of chi square test
% https://nl.mathworks.com/matlabcentral/answers/96572-how-can-i-perform-a-chi-square-test-to-determine-how-statistically-different-two-proportions-are-in
function [p,chi2stat]=chisquaretest(n1,N1,n2,N2,n3,N3,n4,N4,n5,N5)
% Pooled estimate of proportion
p0 = (n1+n2+n3+n4+n5) / (N1+N2+N3+N4+N5);
% Expected counts under H0 (null hypothesis)
n10 = N1*p0;
n20 = N2*p0;
n30 = N3*p0;
n40 = N4*p0;
n50 = N5*p0;
% Chi-square test, by hand
observed = [n1 N1-n1 n2 N2-n2 n3 N3-n3 n4 N4-n4 n5 N5-n5];
expected = [n10 N1-n10 n20 N2-n20 n30 N3-n30 n40 N4-n40 n50 N5-n50];
chi2stat = sum((observed-expected).^2 ./ expected);
p = 1 - chi2cdf(chi2stat,4);
end
